@@ -6,22 +6,22 @@
     <message>
         <location filename="../Session.cpp" line="454"/>
         <source>Bell in session &apos;%1&apos;</source>
-        <translation>Zvonek v sezení &apos;%1&apos;</translation>
+        <translation>Zvonek v sezení „%1“</translation>
     </message>
     <message>
         <location filename="../Session.cpp" line="606"/>
         <source>Session &apos;%1&apos; exited with status %2.</source>
-        <translation>Sezení &apos;%1&apos; ukončeno se stavem %2.</translation>
+        <translation>Sezení „%1“ ukončeno se stavem %2.</translation>
     </message>
     <message>
         <location filename="../Session.cpp" line="608"/>
         <source>Session &apos;%1&apos; crashed.</source>
-        <translation>Sezení &apos;%1&apos; spadlo.</translation>
+        <translation>Sezení „%1“ zhavarovalo.</translation>
     </message>
     <message>
         <location filename="../Session.cpp" line="613"/>
         <source>Session &apos;%1&apos; exited unexpectedly.</source>
-        <translation>Sezení &apos;%1&apos; neočekávaně ukončeno.</translation>
+        <translation>Sezení „%1“ neočekávaně ukončeno.</translation>
     </message>
 </context>
 <context>
@@ -39,12 +39,12 @@
     <message>
         <location filename="../TerminalDisplay.cpp" line="2741"/>
         <source>Paste multiline text</source>
-        <translation type="unfinished"></translation>
+        <translation>Vložit víceřádkový text</translation>
     </message>
     <message>
         <location filename="../TerminalDisplay.cpp" line="2742"/>
         <source>Are you sure you want to paste this text?</source>
-        <translation type="unfinished"></translation>
+        <translation>Opravdu chcete tento text vložit?</translation>
     </message>
     <message>
         <location filename="../TerminalDisplay.cpp" line="3241"/>
@@ -57,7 +57,7 @@
     <message>
         <location filename="../Vt102Emulation.cpp" line="1121"/>
         <source>No keyboard translator available.  The information needed to convert key presses into characters to send to the terminal is missing.</source>
-        <translation>Není k dispozici žádný překladač klávesnice. Chybí tak informace pro převod kódů stisknutých kláves na znaky posílané na terminál.</translation>
+        <translation>Není k dispozici žádný překladač klávesnice. Chybí tak informace pro převod kódů ze stisknutých kláves na znaky posílané na terminál.</translation>
     </message>
 </context>
 <context>
@@ -65,7 +65,7 @@
     <message>
         <location filename="../TerminalDisplay.cpp" line="2748"/>
         <source>Show Details...</source>
-        <translation type="unfinished"></translation>
+        <translation>Zobrazit podrobnosti…</translation>
     </message>
 </context>
 <context>
@@ -74,12 +74,12 @@
         <location filename="../ColorScheme.cpp" line="278"/>
         <location filename="../ColorScheme.cpp" line="293"/>
         <source>Un-named Color Scheme</source>
-        <translation>Nepojmenované barevné schéma</translation>
+        <translation>Nepojmenované schéma barev</translation>
     </message>
     <message>
         <location filename="../ColorScheme.cpp" line="464"/>
         <source>Accessible Color Scheme</source>
-        <translation>Barevné schéma pro uživatele se zrakovou vadou</translation>
+        <translation>Schéma barev pro uživatele se zrakovou vadou</translation>
     </message>
     <message>
         <location filename="../Filter.cpp" line="515"/>
@@ -107,12 +107,12 @@
     <message>
         <location filename="../qtermwidget.cpp" line="468"/>
         <source>Color Scheme Error</source>
-        <translation>Chyba barevného schématu</translation>
+        <translation>Chyba schéma barev</translation>
     </message>
     <message>
         <location filename="../qtermwidget.cpp" line="469"/>
         <source>Cannot load color scheme: %1</source>
-        <translation>Nedaří se načíst barevné schéma: %1</translation>
+        <translation>Nedaří se načíst schéma barev: %1</translation>
     </message>
 </context>
 <context>
